@@ -12,7 +12,7 @@ def initialize(context):
     """$ initialize haufe.monitoring """
     from haufe.monitoring.controlpanel import ControlPanel, ControlPanelId
 
-    LOG.info('Initializing control panel')
+    LOG.debug('Initializing control panel')
     cp = context._ProductContext__app.Control_Panel
     if not ControlPanelId in cp.objectIds():
         monitor = ControlPanel()
@@ -21,7 +21,7 @@ def initialize(context):
 
     monitor = cp[ControlPanelId]
 
-    LOG.info('attempt to register this Zope Instance with ControlPanel')
+    LOG.debug('attempt to register this Zope Instance with ControlPanel')
     from ZODB.POSException import ConflictError
     retry_count = 5
     try:
@@ -35,13 +35,13 @@ def initialize(context):
                 if retry_count > 0: 
                     continue
                 raise # retry action
-        LOG.info('Zope instance successfully registered')
+        LOG.debug('Zope instance successfully registered')
         transaction.commit()
  
     except:
-         LOG.error('Failed to register Zope instance', exc_info=True)
+         LOG.error('Failed to register Zope instance', exc_debug=True)
 
-    LOG.info('Starting GIL monitor')
+    LOG.debug('Starting GIL monitor')
     import gil_monitor
     gil_monitor.start()
 
@@ -50,7 +50,7 @@ def initialize(context):
     #  generation 1 GC at "(allocated - freed) == 140.000"; analyse 140.000 objects
     #  generation 2 GC at "(allocated - freed) == 1.400.000"; analyse all objects
 
-    LOG.info('reconfigured garbage collector thresholds')
+    LOG.debug('reconfigured garbage collector thresholds')
     import gc
     gc.set_threshold(7000, 20, 10)
 
